@@ -9,7 +9,6 @@ package hooks // import "golang.org/x/tools/gopls/internal/hooks"
 
 import (
 	"context"
-	"regexp"
 
 	"golang.org/x/tools/internal/lsp/source"
 	"mvdan.cc/gofumpt/format"
@@ -17,19 +16,16 @@ import (
 )
 
 func Options(options *source.Options) {
+	options.LicensesText = licensesText
 	if options.GoDiff {
 		options.ComputeEdits = ComputeEdits
 	}
-	options.URLRegexp = urlRegexp()
-	options.GofumptFormat = func(ctx context.Context, src []byte) ([]byte, error) {
-		return format.Source(src, format.Options{})
+	options.URLRegexp = xurls.Relaxed()
+	options.GofumptFormat = func(ctx context.Context, langVersion, modulePath string, src []byte) ([]byte, error) {
+		return format.Source(src, format.Options{
+			LangVersion: langVersion,
+			ModulePath:  modulePath,
+		})
 	}
 	updateAnalyzers(options)
 }
-
-func urlRegexp() *regexp.Regexp {
-	// Ensure links are matched as full words, not anywhere.
-	re := regexp.MustCompile(`\b(` + xurls.Relaxed().String() + `)\b`)
-	re.Longest()
-	return re
-}
