@@ -7,9 +7,11 @@ package debug
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
 	"io"
 	"reflect"
+	"runtime"
 	"runtime/debug"
 	"sort"
 	"strings"
@@ -23,16 +25,17 @@ const (
 	PlainText = PrintMode(iota)
 	Markdown
 	HTML
+	JSON
 )
 
 // Version is a manually-updated mechanism for tracking versions.
-const Version = "v0.7.5"
+const Version = "v0.8.1"
 
 // ServerVersion is the format used by gopls to report its version to the
 // client. This format is structured so that the client can parse it easily.
 type ServerVersion struct {
-	Module
-	Deps []*Module `json:"deps,omitempty"`
+	*BuildInfo
+	Version string
 }
 
 type Module struct {
@@ -50,47 +53,24 @@ type ModuleVersion struct {
 // built in module mode, we return a GOPATH-specific message with the
 // hardcoded version.
 func VersionInfo() *ServerVersion {
-	if info, ok := debug.ReadBuildInfo(); ok {
+	if info, ok := readBuildInfo(); ok {
 		return getVersion(info)
 	}
-	path := "gopls, built in GOPATH mode"
+	buildInfo := &BuildInfo{}
+	// go1.17 or earlier, part of s.BuildInfo are embedded fields.
+	buildInfo.Path = "gopls, built in GOPATH mode"
+	buildInfo.GoVersion = runtime.Version()
 	return &ServerVersion{
-		Module: Module{
-			ModuleVersion: ModuleVersion{
-				Path:    path,
-				Version: Version,
-			},
-		},
+		Version:   Version,
+		BuildInfo: buildInfo,
 	}
 }
 
-func getVersion(info *debug.BuildInfo) *ServerVersion {
-	serverVersion := ServerVersion{
-		Module: Module{
-			ModuleVersion: ModuleVersion{
-				Path:    info.Main.Path,
-				Version: info.Main.Version,
-				Sum:     info.Main.Sum,
-			},
-		},
+func getVersion(info *BuildInfo) *ServerVersion {
+	return &ServerVersion{
+		Version:   Version,
+		BuildInfo: info,
 	}
-	for _, d := range info.Deps {
-		m := &Module{
-			ModuleVersion: ModuleVersion{
-				Path:    d.Path,
-				Version: d.Version,
-				Sum:     d.Sum,
-			},
-		}
-		if d.Replace != nil {
-			m.Replace = &ModuleVersion{
-				Path:    d.Replace.Path,
-				Version: d.Replace.Version,
-			}
-		}
-		serverVersion.Deps = append(serverVersion.Deps, m)
-	}
-	return &serverVersion
 }
 
 // PrintServerInfo writes HTML debug info to w for the Instance.
@@ -111,15 +91,29 @@ func (i *Instance) PrintServerInfo(ctx context.Context, w io.Writer) {
 // PrintVersionInfo writes version information to w, using the output format
 // specified by mode. verbose controls whether additional information is
 // written, including section headers.
-func PrintVersionInfo(ctx context.Context, w io.Writer, verbose bool, mode PrintMode) {
+func PrintVersionInfo(_ context.Context, w io.Writer, verbose bool, mode PrintMode) error {
 	info := VersionInfo()
+	if mode == JSON {
+		return printVersionInfoJSON(w, info)
+	}
+
 	if !verbose {
 		printBuildInfo(w, info, false, mode)
-		return
+		return nil
 	}
 	section(w, mode, "Build info", func() {
 		printBuildInfo(w, info, true, mode)
 	})
+	return nil
+}
+
+func printVersionInfoJSON(w io.Writer, info *ServerVersion) error {
+	js, err := json.MarshalIndent(info, "", "\t")
+	if err != nil {
+		return err
+	}
+	_, err = fmt.Fprint(w, string(js))
+	return err
 }
 
 func section(w io.Writer, mode PrintMode, title string, body func()) {
@@ -141,16 +135,17 @@ func section(w io.Writer, mode PrintMode, title string, body func()) {
 
 func printBuildInfo(w io.Writer, info *ServerVersion, verbose bool, mode PrintMode) {
 	fmt.Fprintf(w, "%v %v\n", info.Path, Version)
-	printModuleInfo(w, &info.Module, mode)
+	printModuleInfo(w, info.Main, mode)
 	if !verbose {
 		return
 	}
 	for _, dep := range info.Deps {
-		printModuleInfo(w, dep, mode)
+		printModuleInfo(w, *dep, mode)
 	}
+	fmt.Fprintf(w, "go: %v\n", info.GoVersion)
 }
 
-func printModuleInfo(w io.Writer, m *Module, mode PrintMode) {
+func printModuleInfo(w io.Writer, m debug.Module, _ PrintMode) {
 	fmt.Fprintf(w, "    %s@%s", m.Path, m.Version)
 	if m.Sum != "" {
 		fmt.Fprintf(w, " %s", m.Sum)
